pub struct DynamicList { /* private fields */ }Expand description
A list of reflected values.
Implementations
Sourceimpl DynamicList
impl DynamicList
Sourcepub fn set_represented_type(
&mut self,
represented_type: Option<&'static TypeInfo>,
)
pub fn set_represented_type( &mut self, represented_type: Option<&'static TypeInfo>, )
Sets the type to be represented by this DynamicList.
Panics
Panics if the given type is not a TypeInfo::List.
Sourcepub fn push<T: PartialReflect>(&mut self, value: T)
pub fn push<T: PartialReflect>(&mut self, value: T)
Appends a typed value to the list.
Sourcepub fn push_box(&mut self, value: Box<dyn PartialReflect>)
pub fn push_box(&mut self, value: Box<dyn PartialReflect>)
Appends a Reflect trait object to the list.